<?php

namespace Btravel\Cards\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Cards\Http\Requests\CardRequest;
use Btravel\Cards\Interfaces\CardRepositoryInterface;
use Btravel\Cards\Models\Card;
use Btravel\Cards\Forms\Card as Form;

/**
 * APIController  class for card.
 */
class CardAPIController extends BaseController
{

    /**
     * Initialize card resource controller.
     *
     * @param type CardRepositoryInterface $card
     *
     * @return null
     */
    public function __construct(CardRepositoryInterface $card)
    {
        parent::__construct();
        $this->repository = $card;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Cards\Repositories\Criteria\CardResourceCriteria::class);
    }

    /**
     * Display a list of card.
     *
     * @return Response
     */
    public function index(CardRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Cards\Repositories\Presenter\CardPresenter::class)
            ->paginate();
    }

    /**
     * Display card.
     *
     * @param Request $request
     * @param Model   $card
     *
     * @return Response
     */
    public function show(CardRequest $request, Card $card)
    {
        return $card->setPresenter(\Btravel\Cards\Repositories\Presenter\CardListPresenter::class);
        ;
    }

    /**
     * Create new card.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CardRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('cards::card.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('cards/card/' . $card->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('cards/card');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the card.
     *
     * @param Request $request
     * @param Model   $card
     *
     * @return Response
     */
    public function update(CardRequest $request, Card $card)
    {
        try {
            $data = $request->all();

            $card->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('cards::card.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('cards/card/' . $card->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('cards/card/' . $card->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the card.
     *
     * @param Model   $card
     *
     * @return Response
     */
    public function destroy(CardRequest $request, Card $card)
    {
        try {
            $card->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('cards::card.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('cards/card/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('cards/card/' . $card->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
