<?php

namespace Btravel\Cards\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Cards\Models\CardOffers;

class CardOffersPolicy
{

    /**
     * Determine if the given user can view the card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function view(UserPolicy $user, CardOffers $card_offers)
    {
        if ($user->canDo('cards.card_offers.view') && $user->isAdmin()) {
            return true;
        }

        return $card_offers->user_id == user_id() && $card_offers->user_type == user_type();
    }

    /**
     * Determine if the given user can create a card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('cards.card_offers.create');
    }

    /**
     * Determine if the given user can update the given card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function update(UserPolicy $user, CardOffers $card_offers)
    {
        if ($user->canDo('cards.card_offers.edit') && $user->isAdmin()) {
            return true;
        }

        return $card_offers->user_id == user_id() && $card_offers->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CardOffers $card_offers)
    {
        return $card_offers->user_id == user_id() && $card_offers->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CardOffers $card_offers)
    {
        if ($user->canDo('cards.card_offers.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given card_offers.
     *
     * @param UserPolicy $user
     * @param CardOffers $card_offers
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CardOffers $card_offers)
    {
        if ($user->canDo('cards.card_offers.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
