<?php

namespace Btravel\Cards\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Cards\Models\Card;

class CardPolicy
{

    /**
     * Determine if the given user can view the card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function view(UserPolicy $user, Card $card)
    {
        if ($user->canDo('cards.card.view') && $user->isAdmin()) {
            return true;
        }

        return $card->user_id == user_id() && $card->user_type == user_type();
    }

    /**
     * Determine if the given user can create a card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('cards.card.create');
    }

    /**
     * Determine if the given user can update the given card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function update(UserPolicy $user, Card $card)
    {
        if ($user->canDo('cards.card.edit') && $user->isAdmin()) {
            return true;
        }

        return $card->user_id == user_id() && $card->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Card $card)
    {
        return $card->user_id == user_id() && $card->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Card $card)
    {
        if ($user->canDo('cards.card.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given card.
     *
     * @param UserPolicy $user
     * @param Card $card
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Card $card)
    {
        if ($user->canDo('cards.card.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
