<?php

namespace Btravel\Cards\Providers;

use Illuminate\Support\ServiceProvider;

class CardsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'cards');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'cards');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCards();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCards()
    {
        $this->app->bind('cards', function($app) {
            return new Cards($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Cards', 'Lavalite\Cards\Facades\Cards');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.cards', function ($app) {
            return $this->app->make('Btravel\Cards\Cards');
        });

        // Bind CardOffers to repository
        $this->app->bind(
            'Btravel\Cards\Interfaces\CardOffersRepositoryInterface',
            \Btravel\Cards\Repositories\Eloquent\CardOffersRepository::class
        );
        // Bind Card to repository
        $this->app->bind(
            'Btravel\Cards\Interfaces\CardRepositoryInterface',
            \Btravel\Cards\Repositories\Eloquent\CardRepository::class
        );

        $this->app->register(\Btravel\Cards\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Cards\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and cards's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'btravel.cards'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCards::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.cards'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/cards.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/cards')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/cards')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
