<?php

namespace Btravel\Cards\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Cards\Models\Cards;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Cards\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/cards/card_offers/*')) {
            Route::bind('card_offers', function ($card_offers) {
                $card_offersrepo = $this->app->make('Btravel\Cards\Interfaces\CardOffersRepositoryInterface');
                return $card_offersrepo->findorNew($card_offers);
            });
        }

        if (Request::is('*/cards/card/*')) {
            Route::bind('card', function ($card) {
                $cardrepo = $this->app->make('Btravel\Cards\Interfaces\CardRepositoryInterface');
                return $cardrepo->findorNew($card);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
